﻿#region Header
//
// (C) Copyright 2011-2012 by Autodesk, Inc.
//
// Permission to use, copy, modify, and distribute this software in
// object code form for any purpose and without fee is hereby granted,
// provided that the above copyright notice appears in all copies and
// that both that copyright notice and the limited warranty and
// restricted rights notice below appear in all supporting
// documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE. AUTODESK, INC.
// DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
// UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is subject to
// restrictions set forth in FAR 52.227-19 (Commercial Computer
// Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
// (Rights in Technical Data and Computer Software), as applicable.
//
#endregion // Header

#region Namespaces
using System;
using Autodesk.Revit.DB;
using Autodesk.Revit.UI;
using System.Diagnostics;
#endregion // Namespaces

namespace Estorage
{
  class Util
  {
    /// <summary>
    /// Return an English plural suffix for the given 
    /// number of items, i.e. 's' for zero or more 
    /// than one, and nothing for exactly one.
    /// </summary>
    public static string PluralSuffix( int n )
    {
      return 1 == n ? "" : "s";
    }

    /// <summary>
    /// Return a full stop dot for zero items,
    /// and a colon for more than zero.
    /// </summary>
    public static string DotOrColon( int n )
    {
      return 0 == n ? "." : ":";
    }

    /// <summary>
    /// Display an informational message 
    /// in a Revit task dialogue.
    /// </summary>
    public static void InfoMessage( string instruction )
    {
      Debug.Print( instruction );

      TaskDialog a = new TaskDialog( 
        "Extensible Storage" );

      a.MainInstruction = instruction;
      a.Show();
    }

    /// <summary>
    /// Display an informational message 
    /// in a Revit task dialogue.
    /// </summary>
    public static void InfoMessage(
      string instruction,
      string content )
    {
      Debug.Print( instruction );
      Debug.Print( content );

      TaskDialog a = new TaskDialog(
        "Extensible Storage" );

      a.MainInstruction = instruction;
      a.MainContent = content;
      a.Show();
    }

    /// <summary>
    /// Return *all* elements in the document.
    /// </summary>
    public static FilteredElementCollector GetAllElements( 
      Document doc )
    {
      return new FilteredElementCollector( doc ).WherePasses(
        new LogicalOrFilter(
          new ElementIsElementTypeFilter( false ),
          new ElementIsElementTypeFilter( true ) ) );
    }
  }

  public static class
    JtFilteredElementCollectorExtensionMethods
  {
    public static FilteredElementCollector HasEstorageData(
      this FilteredElementCollector a )
    {
      return a;
    }
  }
}
